searchData={"items":[{"type":"module","title":"TwitchAPI","doc":"Twitch API.\n\nYou can make requests to Twitch API endpoints.","ref":"TwitchAPI.html"},{"type":"module","title":"Examples - TwitchAPI","doc":"```elixir\n  client_id = \"asdsdksdl93roi39\"\n  access_token = \"09wriujr329jd023920dk203kd0932d\"\n\n  auth = TwitchAPI.Auth.new(client_id, access_token)\n\n  case TwitchAPI.get(auth, \"/users\") do\n    {:ok, %{body: users}} ->\n      IO.inspect(users, label: \"Successful response body\")\n\n    {:error, resp} ->\n      IO.inspect(resp, label: \"We got an error\")\n  end\n```","ref":"TwitchAPI.html#module-examples"},{"type":"function","title":"TwitchAPI.client/1","doc":"Build a base `t:Req.Request.t/0` for Twitch API requests.\n\nYou can pass either this or a `t:TwitchAPI.Auth.t/0` struct to the\nrequest functions.\n\nNOTE: You probably only want to use this directly if you want to do something\ndifferent than the default.","ref":"TwitchAPI.html#client/1"},{"type":"function","title":"TwitchAPI.delete/3","doc":"Make a Twitch API DELETE request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#delete/3"},{"type":"function","title":"TwitchAPI.delete!/3","doc":"Make a Twitch API DELETE request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#delete!/3"},{"type":"function","title":"TwitchAPI.get/3","doc":"Make a Twitch API GET request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#get/3"},{"type":"function","title":"TwitchAPI.get!/3","doc":"Make a Twitch API GET request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#get!/3"},{"type":"function","title":"TwitchAPI.head/3","doc":"Make a Twitch API HEAD request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#head/3"},{"type":"function","title":"TwitchAPI.head!/3","doc":"Make a Twitch API HEAD request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#head!/3"},{"type":"function","title":"TwitchAPI.patch/3","doc":"Make a Twitch API PATCH request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#patch/3"},{"type":"function","title":"TwitchAPI.patch!/3","doc":"Make a Twitch API PATCH request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#patch!/3"},{"type":"function","title":"TwitchAPI.post/3","doc":"Make a Twitch API POST request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#post/3"},{"type":"function","title":"TwitchAPI.post!/3","doc":"Make a Twitch API POST request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#post!/3"},{"type":"function","title":"TwitchAPI.put/3","doc":"Make a Twitch API PUT request.\nReturns `:ok` or `:error` tuples.","ref":"TwitchAPI.html#put/3"},{"type":"function","title":"TwitchAPI.put!/3","doc":"Make a Twitch API PUT request.\nRaises on error or unexpected HTTP status.","ref":"TwitchAPI.html#put!/3"},{"type":"type","title":"TwitchAPI.body_params/0","doc":"","ref":"TwitchAPI.html#t:body_params/0"},{"type":"module","title":"TwitchAPI.Auth","doc":"Twitch API Auth (and struct).","ref":"TwitchAPI.Auth.html"},{"type":"function","title":"TwitchAPI.Auth.merge_string_params/2","doc":"Merge string params into `Auth` struct.","ref":"TwitchAPI.Auth.html#merge_string_params/2"},{"type":"function","title":"TwitchAPI.Auth.new/1","doc":"Make a new `Auth` struct with a `client_id`.","ref":"TwitchAPI.Auth.html#new/1"},{"type":"function","title":"TwitchAPI.Auth.new/2","doc":"Make a new `Auth` struct with a `client_id` and `client_secret`.","ref":"TwitchAPI.Auth.html#new/2"},{"type":"function","title":"TwitchAPI.Auth.new/3","doc":"Make a new `Auth` struct with a `client_id`, `client_secret`, and `access_token`.","ref":"TwitchAPI.Auth.html#new/3"},{"type":"function","title":"TwitchAPI.Auth.put_access_token/2","doc":"Add an `access_token` to the `Auth` struct.","ref":"TwitchAPI.Auth.html#put_access_token/2"},{"type":"function","title":"TwitchAPI.Auth.put_client_secret/2","doc":"Add a `client_secret` to the `Auth` struct.","ref":"TwitchAPI.Auth.html#put_client_secret/2"},{"type":"function","title":"TwitchAPI.Auth.token_get_from_code/3","doc":"Get an access token with an authorization code.\nhttps://dev.twitch.tv/docs/authentication/getting-tokens-oauth/#authorization-code-grant-flow\n\nIf the request succeeds, it returns an access token and refresh token.\n\n    {\n      \"access_token\": \"rfx2uswqe8l4g1mkagrvg5tv0ks3\",\n      \"expires_in\": 14124,\n      \"refresh_token\": \"5b93chm6hdve3mycz05zfzatkfdenfspp1h1ar2xxdalen01\",\n      \"scope\": [\n        \"channel:moderate\",\n        \"chat:edit\",\n        \"chat:read\"\n      ],\n      \"token_type\": \"bearer\"\n    }","ref":"TwitchAPI.Auth.html#token_get_from_code/3"},{"type":"function","title":"TwitchAPI.Auth.token_refresh/1","doc":"Refresh an access token.\nhttps://dev.twitch.tv/docs/authentication/refresh-tokens\n\nIf the request succeeds, the response contains the new access token, refresh\ntoken, and scopes associated with the new grant. Because refresh tokens may\nchange, your app should safely store the new refresh token to use the next time.\n\n    {\n      \"access_token\": \"1ssjqsqfy6bads1ws7m03gras79zfr\",\n      \"refresh_token\": \"eyJfMzUtNDU0OC4MWYwLTQ5MDY5ODY4NGNlMSJ9%asdfasdf=\",\n      \"scope\": [\n        \"channel:read:subscriptions\",\n        \"channel:manage:polls\"\n      ],\n      \"token_type\": \"bearer\"\n    }\n\nThe following example shows what the response looks like if the request fails.\n\n    {\n      \"error\": \"Bad Request\",\n      \"status\": 400,\n      \"message\": \"Invalid refresh token\"\n    }","ref":"TwitchAPI.Auth.html#token_refresh/1"},{"type":"function","title":"TwitchAPI.Auth.token_revoke/1","doc":"Revoke an access token.\nhttps://dev.twitch.tv/docs/authentication/revoke-tokens\n\nIf the revocation succeeds, the request returns HTTP status code 200 OK (with no body).\n\nIf the revocation fails, the request returns one of the following HTTP status codes:\n\n * 400 Bad Request if the client ID is valid but the access token is not.\n\n    {\n      \"status\": 400,\n      \"message\": \"Invalid token\"\n    }\n\n * 404 Not Found if the client ID is not valid.\n\n    {\n      \"status\": 404,\n      \"message\": \"client does not exist\"\n    }","ref":"TwitchAPI.Auth.html#token_revoke/1"},{"type":"function","title":"TwitchAPI.Auth.token_validate/1","doc":"Validate an access token.\nhttps://dev.twitch.tv/docs/authentication/validate-tokens/#how-to-validate-a-token\n\nIf the token is valid, the request returns HTTP status code 200 and the\nresponse’s body contains the following JSON object:\n\n    {\n      \"client_id\": \"wbmytr93xzw8zbg0p1izqyzzc5mbiz\",\n      \"login\": \"twitchdev\",\n      \"scopes\": [\n        \"channel:read:subscriptions\"\n      ],\n      \"user_id\": \"141981764\",\n      \"expires_in\": 5520838\n    }\n\nIf the token is not valid, the request returns HTTP status code 401 and the\nresponse’s body contains the following JSON object:\n\n    {\n      \"status\": 401,\n      \"message\": \"invalid access token\"\n    }","ref":"TwitchAPI.Auth.html#token_validate/1"},{"type":"type","title":"TwitchAPI.Auth.t/0","doc":"","ref":"TwitchAPI.Auth.html#t:t/0"}],"content_type":"text/markdown"}